# 📖 Summary
- [📖 Summary](#📖-summary)
- [💼 About Bullhorn](#💼-about-bullhorn)
  - [😍 Why is it a big deal for Bullhorn customers & partners?](#😍-why-is-it-a-big-deal-for-bullhorn-customers--partners)
- [🔧 How does it work?](#🔧-how-does-it-work)
  - [📊 Data integration capabilities:](#📊-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#🧠-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#🔌-connector-actions)
- [💍 Quick Start Examples](#💍-quick-start-examples)
- [🔗 Useful Links](#🔗-useful-links)
- [👏 Special Thanks](#👏-special-thanks)


# 💼 About Bullhorn

> Transform Your Business with Bullhorn Staffing and Recruitment Software

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216124159-5bf2ff28-66a7-4327-ba1d-e417748d4ab5.png width=90% height=100% >
</p>

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216124837-d8dd8f03-dae5-4298-ba57-cef2c00df4dd.png width=90% height=100% >
</p>

## 😍 Why is it a big deal for Bullhorn customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Bullhorn customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Bullhorn customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Bullhorn to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Bullhorn.
- ⬅️ Send Jobs data from Bullhorn to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Bullhorn.

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/9dc5543c-5507-4317-ad23-c1702153a972 width=90% height=100% >
</p>

## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Bullhorn**)

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/217298819-29d43799-422d-48f4-8995-272d0af66cbe.gif width=90% height=100% >
</p>

# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Create jobs in hrflow**](docs/create_jobs_in_hrflow.md) | Send **created** 'job(s)' _from_  _to_ HrFlow |
| [**Update jobs in hrflow**](docs/update_jobs_in_hrflow.md) | Send **updated** 'job(s)' _from_  _to_ HrFlow |
| [**Archive jobs in hrflow**](docs/archive_jobs_in_hrflow.md) | Send **archived** 'job(s)' _from_  _to_ HrFlow |
| [**Create profiles in hrflow**](docs/create_profiles_in_hrflow.md) | Send **created** 'profile(s)' _from_  _to_ HrFlow |
| [**Update profiles in hrflow**](docs/update_profiles_in_hrflow.md) | Send **updated** 'profile(s)' _from_  _to_ HrFlow |
| [**Archive profiles in hrflow**](docs/archive_profiles_in_hrflow.md) | Send **archived** 'profile(s)' _from_  _to_ HrFlow |


</p>


# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216126235-03319722-c10b-460d-b19d-0e4240fe652c.png width=90% height=100% >
</p>

Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.


# 🔗 Useful Links

- 📄 Visit [Bullhorn](https://www.bullhorn.com/) to learn more.
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/v2/connectors/bullhorn) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai : [Nedhir Ebnou](https://github.com/itsnedhir) - Software Engineer & Abdellahi Mezid - Software Engineer
- 🤝 Bullhorn : Arne LOOTEN - Partner Manager